@@ -281,7 +281,6 @@ int handle_error(t_session *session, int error_code) {
 int run_program(t_session *session, char *program, int return_code) {
 	pid_t pid;
 	char ip[MAX_IP_STR_LEN], value[10], *pos, slash = '/';
-	int result;
 
 	switch (pid = fork()) {
 		case -1:
@@ -326,7 +325,9 @@ int run_program(t_session *session, char *program, int return_code) {
 #endif
 				if (pos != NULL) {
 					*pos = '\0';
-					result = chdir(program);
+					if (chdir(program) == -1) {
+						exit(EXIT_FAILURE);
+					}
 					*pos = slash;
 				}
 
@@ -367,7 +368,7 @@ t_access allow_client(t_session *session) {
  */
 int serve_client(t_session *session) {
 	int result, length;
-	char *search, *conffile, *qmark, chr, *client_ip;
+	char *search, *qmark, chr, *client_ip;
 	t_host *host_record;
 	t_access access;
 	t_deny_body *deny_body;
@@ -493,6 +494,15 @@ int serve_client(t_session *session) {
 	rproxy = session->host->rproxy;
 	while (rproxy != NULL) {
 		if (rproxy_match(rproxy, session->request_uri)) {
+			if (rproxy_loop_detected(session->headerfields)) {
+				return 508;
+			}
+
+			if ((qmark = strchr(session->uri, '?')) != NULL) {
+				*qmark = '\0';
+				session->vars = qmark + 1;
+			}
+
 			if (validate_url(session) == false) {
 				return -1;
 			}
@@ -503,8 +513,41 @@ int serve_client(t_session *session) {
 				}
 			}
 
-			if (rproxy_loop_detected(session->headerfields)) {
-				return 508;
+			if (duplicate_host(session) == false) {
+				return 500;
+			} else if ((result = uri_to_path(session)) != 200) {
+				return result;
+			} else if (load_user_config(session) == -1) {
+				return 500;
+			} else if ((result = copy_directory_settings(session)) != 200) {
+				return result;
+			}
+
+			switch (access = allow_client(session)) {
+				case deny:
+					log_error(session, fb_accesslist);
+					return 403;
+				case allow:
+					break;
+				case pwd:
+				case unspecified:
+					if (http_authentication_oke(session, access == unspecified) == false) {
+						return 401;
+					}
+			}
+
+			if (session->host->prevent_xss) {
+				prevent_xss(session);
+			}
+
+			if (session->host->prevent_csrf) {
+				prevent_csrf(session);
+			}
+
+			if (session->host->prevent_sqli) {
+				if ((result = prevent_sqli(session)) != 0) {
+					return result;
+				}
 			}
 
 			return proxy_request(session, rproxy);
@@ -535,6 +578,8 @@ int serve_client(t_session *session) {
 				return 501;
 			}
 			break;
+		default:
+			break;
 	}
 
 #ifdef ENABLE_TOOLKIT
@@ -612,8 +657,6 @@ int serve_client(t_session *session) {
 		return 500;
 	}
 
-	/* Validate URL again after rewrite and decoding
-	 */
 	if (validate_url(session) == false) {
 		return -1;
 	}
@@ -624,27 +667,8 @@ int serve_client(t_session *session) {
 
 	/* Load configfile from directories
 	 */
-	search = session->file_on_disk;
-	while (*search != '\0') {
-		if (*search == '/') {
-			length = search - session->file_on_disk + 1;
-			if ((conffile = (char*)malloc(length + 10)) == NULL) {
-				result = 500;
-			} else {
-				memcpy(conffile, session->file_on_disk, length);
-				memcpy(conffile + length, ".hiawatha\0", 10);
-				if (read_user_configfile(conffile, session->host, &(session->tempdata)) > 0) {
-					log_file_error(session, conffile, "error in configuration file");
-					result = 500;
-				}
-				free(conffile);
-			}
-		}
-		if (result == 200) {
-			search++;
-		} else {
-			return result;
-		}
+	if (load_user_config(session) == -1) {
+		return 500;
 	}
 
 	if ((result = copy_directory_settings(session)) != 200) {
@@ -1444,8 +1468,10 @@ int run_server(t_settings *settings) {
 	t_binding          *binding;
 	t_config           *config;
     fd_set             read_fds;
+#ifndef CYGWIN
 	struct stat        status;
 	mode_t             access_rights;
+#endif
 
 	config = default_config();
 	if (chdir(settings->config_dir) == -1) {
