@@ -21,6 +21,10 @@
 #include "session.h"
 #include "libstr.h"
 #include "command.h"
+#include "log.h"
+#ifdef ENABLE_MONITOR
+#include "monitor.h"
+#endif
 
 #define REQUEST_BUFFER_CHUNK     4 * KILOBYTE
 #define NO_REQUEST_LIMIT_TIME  300
