@@ -411,7 +411,7 @@ t_filelist *read_filelist(char *directory) {
 	DIR *dp;
 	t_filelist *filelist = NULL, *file;
 	char *filename;
-	int dir_len, stat_status;
+	int stat_status;
 	struct stat status;
 	struct dirent *dir_info;
 
@@ -420,7 +420,6 @@ t_filelist *read_filelist(char *directory) {
 	} else if ((dp = opendir(directory)) == NULL) {
 		return NULL;
 	}
-	dir_len = strlen(directory);
 
 	while ((dir_info = readdir(dp)) != NULL) {
 		if ((dir_info->d_name[0] != '.') || (strcmp(dir_info->d_name, "..") == 0)) {
