@@ -302,8 +302,10 @@ int get_client_crt_info(ssl_context *ssl, char *subject, char *issuer, int lengt
 /* Close SSL connection
  */
 void ssl_close(ssl_context *ssl) {
-	ssl_close_notify(ssl);
-	ssl_free(ssl);
+	if (ssl != NULL) {
+		ssl_close_notify(ssl);
+		ssl_free(ssl);
+	}
 }
 
 /* Clean up SSL library
@@ -342,7 +344,7 @@ int ssl_send_completely(ssl_context *ssl, const char *buffer, int size) {
 	int bytes_written, total_written = 0;
 
 	while (total_written < size) {
-		if ((bytes_written = ssl_write(ssl, buffer + total_written, size - total_written)) == -1) {
+		if ((bytes_written = ssl_write(ssl, (unsigned char*)buffer + total_written, size - total_written)) == -1) {
 			return -1;
 		} else {
 			total_written += bytes_written;
