@@ -333,6 +333,41 @@ bool is_volatile_object(t_session *session) {
 	return false;
 }
 
+/* Load configfile from directories
+ */
+int load_user_config(t_session *session) {
+	char *search, *conffile;
+	int length, result;
+
+	if (session->file_on_disk == NULL) {
+		return 0;
+	}
+
+	search = session->file_on_disk;
+	while (*search != '\0') {
+		if (*search == '/') {
+			length = search - session->file_on_disk + 1;
+			if ((conffile = (char*)malloc(length + 10)) == NULL) {
+				return -1;
+			} else {
+				memcpy(conffile, session->file_on_disk, length);
+				memcpy(conffile + length, ".hiawatha\0", 10);
+				result = read_user_configfile(conffile, session->host, &(session->tempdata));
+				free(conffile);
+
+				if (result == -1) {
+					log_file_error(session, conffile, "error in configuration file");
+					return -1;
+				}
+			}
+		}
+
+		search++;
+	}
+
+	return 0;
+}
+
 /* Copy the settings from a directory-record to the active host-record.
  */
 int copy_directory_settings(t_session *session) {
@@ -565,7 +600,7 @@ int init_sqli_detection(void) {
 
 /* Prevent SQL injection
  */
-int prevent_sqli(t_session *session, char *str, int length) {
+static int prevent_sqli_str(t_session *session, char *str, int length) {
 	char *data;
 	t_sqli_pattern *pattern;
 	int result = 0;
@@ -606,6 +641,59 @@ int prevent_sqli(t_session *session, char *str, int length) {
 	return result;
 }
 
+int prevent_sqli(t_session *session) {
+	if (session->request_uri != NULL) {
+		switch (prevent_sqli_str(session, session->request_uri, strlen(session->request_uri))) {
+			case -1:
+				return 500;
+			case 0:
+				break;
+			default:
+				session->error_cause = ec_SQL_INJECTION;
+				return -1;
+		}
+	}
+/*
+	if (session->vars != NULL) {
+		switch (prevent_sqli_str(session, session->vars, strlen(session->vars))) {
+			case -1:
+				return 500;
+			case 0:
+				break;
+			default:
+				session->error_cause = ec_SQL_INJECTION;
+				return -1;
+		}
+	}
+*/
+
+	if (session->body != NULL) {
+		switch (prevent_sqli_str(session, session->body, session->content_length)) {
+			case -1:
+				return 500;
+			case 0:
+				break;
+			default:
+				session->error_cause = ec_SQL_INJECTION;
+				return -1;
+		}
+	}
+
+	if (session->cookie != NULL) {
+		switch (prevent_sqli_str(session, session->cookie, strlen(session->cookie))) {
+			case -1:
+				return 500;
+			case 0:
+				break;
+			default:
+				session->error_cause = ec_SQL_INJECTION;
+				return -1;
+		}
+	}
+
+	return 0;
+}
+
 /* Prevent Cross-site Request Forgery
  */
 int prevent_csrf(t_session *session) {
