@@ -132,12 +132,13 @@ int  get_target_extension(t_session *session);
 int  get_homedir(t_session *session, char *username);
 bool duplicate_host(t_session *session);
 bool is_volatile_object(t_session *session);
+int  load_user_config(t_session *session);
 int  copy_directory_settings(t_session *session);
 bool client_is_rejected_bot(t_session *session);
 int  remove_port_from_hostname(char *hostname, t_binding *binding);
 int  prevent_xss(t_session *session);
 int  init_sqli_detection(void);
-int  prevent_sqli(t_session *session, char *str, int length);
+int  prevent_sqli(t_session *session);
 int  prevent_csrf(t_session *session);
 void close_socket(t_session *session);
 
