@@ -389,7 +389,7 @@ bool toolkit_rules_oke(t_url_toolkit *url_toolkit) {
 }
 
 static int do_rewrite(char *url, regex_t *regexp, regmatch_t *pmatch, char *rep, char **new_url, int loop) {
-	int ofs, len, len_rep, i, n;
+	int ofs, len, i, n;
 	char *repl, *c, *sub, *tmp;
 	bool first_run = true;
 
@@ -452,7 +452,6 @@ static int do_rewrite(char *url, regex_t *regexp, regmatch_t *pmatch, char *rep,
 		/* Replace pattern with replacement string.
 		 */
 		len = pmatch[0].rm_eo - ofs;
-		len_rep = strlen(repl);
 		if (replace(url, ofs, len, repl, new_url) == -1) {
 			free(repl);
 			return -1;
