@@ -660,7 +660,7 @@ void check_url_toolkit(char *config_dir, char **toolkit_id) {
 			printf("Bad URL: missing leading slash.\n");
 		}
 
-		init_toolkit_options(&options, ".", url_toolkit, false, NULL);
+		init_toolkit_options(&options, ".", url_toolkit, false, false, NULL);
 
 		id = toolkit_id;
 		while (*id != NULL) {
